/*
 * $Copyright(c) 2002-2003, 2007-2008 Progress Software Corporation (PSC). All rights reserved.$
 * $Copyright (c) 2013-2018 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 */

#ifndef IAF_TIMESTAMP_CONFIG_H
#define IAF_TIMESTAMP_CONFIG_H

#include <AP_Types.h>
#include <AP_Logger.h>
#include <IAF_Platform.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/** \file
 * Hires Timestamps configuration support
 */


/**
 * IAF_TimestampConfig
 *
 * Structure to hold per-plugin (transport, codec and Semantic Mapper)
 * timestamp-handling settings passed in from the configuration file.
 */
typedef struct {
	/**
	 * If true, the plug-in should record timestamps for all upstream events
	 * it processes, and pass these along to the upstream component, if any.
	 */
	AP_bool recordUpstream;

	/**
	 * If true, the plug-in should record timestamps for all downstream
	 * events it processes, and pass these along to the downstream component, if any.
	 */
	AP_bool recordDownstream;

	/**
	 * If true, the plug-in should log the latency for all upstream events it
	 * it processes, at the logging level given by the logLevel member. A plug-in may
	 * enable upstream timestamp recording if upstream logging is enabled
	 */
	AP_bool logUpstream;

	/**
	 * If true, the plug-in should log the latency for all downstream events
	 * it processes, at the logging level given by the logLevel member. A plug-in may
	 * implicitly enable downstream timestamp recording if downstream logging is enabled.
	 */

	AP_bool logDownstream;

	/**
	 * If true, the plug-in should log the "round trip" latency for all events
	 * it processes in either direction, if possible. At its simplest, the round trip latency
	 * can just be the difference between the largest and smallest timestamps passed to the
	 * plug-in, or an individual plug-in may choose to present some more plug-in-specific
	 * latency number. As with the other logging options, the logging level given by the
	 * logLevel member should be used.
	 */

	AP_bool logRoundtrip;
	enum AP_LogLevel logLevel;
} IAF_TimestampConfig;

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif /* IAF_TIMESTAMP_CONFIG_H */
